==> 0.2.1.tar.gz: lib/utils/empty_widget.dart <==
import 'package:flutter/material.dart';
import 'package:loyalty_foop/utils/text_styling.dart';


import 'colors.dart';
import 'hexColors.dart';
import 'localization.dart';
import 'locator.dart';



class EmptyWidget extends StatelessWidget {
  final String? message;

 final  AppLocalizations? localizations = locatorRewards<AppLocalizations>();

  EmptyWidget({this.message});

  @override
  Widget build(BuildContext context) {
    TextStyleElements styleElements = TextStyleElements(context);
    return SingleChildScrollView(
      child: Container(
        child: Column(
          mainAxisSize: MainAxisSize.min,
          mainAxisAlignment: MainAxisAlignment.center,
          children: [
            Container(
              height: 64,
              width: 64,
              decoration: BoxDecoration(
                  image: DecorationImage(
                    fit: BoxFit.contain,
                    image: AssetImage('assets/appimages/empty.png'),
                  )),
            ),
            Padding(
              padding: EdgeInsets.only(top: 24, left: 24, right: 24),
              child: Text(
                message!.isEmpty
                    ? localizations!.translate('no_data')
                    : message!,
                textAlign: TextAlign.center,
                style: styleElements
                    .subtitle1ThemeScalable(context)
                    .copyWith(color: HexColor(AppColors.appColorBlack35)),
              ),
            )
          ],
        ),
      ),
    );
  }
}

==> 0.10.1.tar.gz: lib/utils/empty_widget.dart <==
import 'package:flutter/material.dart';
import 'package:loyalty_management_tool/utils/text_styling.dart';


import 'colors.dart';
import 'hexColors.dart';
import 'localization.dart';
import 'locator.dart';



class EmptyWidget extends StatelessWidget {
  final String? message;


  EmptyWidget({this.message});

  @override
  Widget build(BuildContext context) {
    TextStyleElements styleElements = TextStyleElements(context);
    return SingleChildScrollView(
      child: Container(
        child: Column(
          mainAxisSize: MainAxisSize.min,
          mainAxisAlignment: MainAxisAlignment.center,
          children: [
            Container(
              height: 64,
              width: 64,
              decoration: BoxDecoration(
                  image: DecorationImage(
                    fit: BoxFit.contain,
                    image: AssetImage('packages/loyalty_management_tool/assets/appimages/empty.png',),
                  )),
            ),
            Padding(
              padding: EdgeInsets.only(top: 24, left: 24, right: 24),
              child: Text(
                message!.isEmpty
                    ? AppLocalizationsRewards.of(context)!.translate('no_data')
                    : message!,
                textAlign: TextAlign.center,
                style: styleElements
                    .subtitle1ThemeScalable(context)
                    .copyWith(color: HexColor(AppColors.appColorBlack35)),
              ),
            )
          ],
        ),
      ),
    );
  }
}
